# Cleanup R environment
rm(list=ls())               # Remove data frames and values
dev.off()                   # Remove plots
cat("\014")                 # Remove results from the console

# Set output to be written with comma or dot for separating decimals
options(OutDec= ".")

# Set working directory
setwd("C:/Taiacupeba_SedimentModel")

# Load data sets
TaiacupebaMirim <- read.csv("BedGradation_TaiacupebaMirim.csv", header=T)
Balainho <- read.csv("BedGradation_Balainho.csv", header=T)
TaiacupebaGuacu <- read.csv("BedGradation_TaiacupebaGuacu.csv", header=T)
JUTAChannel <- read.csv("BedGradation_JUTAChannel.csv", header=T)

# Compute d50
d50.TaicupebaMirim <- approx(TaiacupebaMirim$PERCENT_FINER[8:9],
                             TaiacupebaMirim$DIAMETER[8:9], 50, method="linear")
d50.Balainho <- approx(Balainho$PERCENT_FINER[6:7],
                       Balainho$DIAMETER[6:7], 50, method="linear")
d50.TaicupebaGuacu <- approx(TaiacupebaGuacu$PERCENT_FINER[7:8],
                             TaiacupebaGuacu$DIAMETER[7:8], 50, method="linear")
d50.JUTAChannel <- approx(JUTAChannel$PERCENT_FINER[7:8],
                           JUTAChannel$DIAMETER[7:8], 50, method="linear")

# Plot Bed Gradation Curve
plot(Balainho$DIAMETER, Balainho$PERCENT_FINER, log = "x", xlab = "Diameter, in millimeters",
     ylab = "Percent finer", xlim = c(0.001, 32),
     xaxt = "n", yaxt = "n", type = "l", lwd = 3, cex.lab = 1.5, col = "red")
lines(TaiacupebaMirim$DIAMETER, TaiacupebaMirim$PERCENT_FINER,
      lwd = 3, col = "blue")
lines(TaiacupebaGuacu$DIAMETER, TaiacupebaGuacu$PERCENT_FINER,
      lwd = 3, col = 139)
lines(JUTAChannel$DIAMETER, JUTAChannel$PERCENT_FINER,
      lwd = 3, col = "black")
abline(h = 50, lty = 2)
axis(1, at = c(0.001, 0.01, 0.1, 1, 10), labels = c(0.001, 0.01, 0.1, 1, 10),
     tck = 0.04, cex.axis = 1.5)
rug(x = c(seq(0.001, 0.01, 0.001), seq(0.01, 0.1, 0.01), seq(0.1, 1, 0.1),
          seq(1, 10, 1), seq(10, 100, 10)), ticksize = 0.02, side = 1)
axis(2, at = seq(0, 100, 20), labels = seq(0, 100, 20), tck = 0.03, cex.axis = 1.5)
rug(x = seq(10, 100, 10), ticksize = 0.02, side = 2)
axis(3, at = c(0.001, 0.01, 0.1, 1, 10), labels = F, tck = 0.04, cex.axis = 1.5)
rug(x = c(seq(0.001, 0.01, 0.001), seq(0.01, 0.1, 0.01), seq(0.1, 1, 0.1),
          seq(1, 10, 1), seq(10, 100, 10)), ticksize = 0.02, side = 3)
axis(4, at = seq(0, 100, 20), labels = F, tck = 0.03, cex.axis = 1.5)
rug(x = seq(10, 100, 10), ticksize = 0.02, side = 4)
legend("topleft", inset = 0.05, c("Taiacupeba Mirim", "Balainho", "Taiacupeba Guacu", "JUTA Channel"),
       lty = 1, lwd = 3, col = c("blue", "red", 139, "black"), bty = "n",
       cex = 1.5, title = "Explanation", title.adj = 0.1)