# Cleanup R environment
rm(list=ls())               # Remove data frames and objects
dev.off()                   # Remove plots
cat("\014")                 # Remove results from the console

# Set output to be written with comma or dot for separating decimals
options(OutDec= ".")

# Set working directory
setwd("C:/Taiacupeba_SedimentModel")

# Load data sets
DailyQ <- read.csv("DailyDischarge_TaiacupebaGuacu.csv",header=T)
  DailyQ$DATE <- as.Date(DailyQ$DATE, "%m/%d/%Y")
SedData <- read.csv("SedimentData_TaiacupebaGuacu.csv",header=T)
  SedData$SAMPLE_DATE <- as.Date(SedData$SAMPLE_DATE, "%m/%d/%Y")

# Install libraries for the first run
# install.packages("hydroTSM")
# install.packages("zoo")
# install.packages("xts")
# install.packages("e1071")
# install.packages("gstat")
# install.packages("spacetime")
# install.packages("intervals")
# install.packages("FNN")
# install.packages("automap")
# install.packages("reshape")
  
# Load hydroTSM
library(hydroTSM)

# Compute Flow Duration Curve
flowDC <- fdc(DailyQ$DISCHARGE)

# Create a data frame with flowDC values for plotting
df1 <- data.frame(Q = DailyQ$DISCHARGE, PercentTime = flowDC)

# Sort data frame for scatter plotting
df1 <- df1[order(df1$PercentTime),]

# Associate sediment sampled events to flowDC
sampledQ <- (df1$Q %in% SedData$Q)
df2 <- df1[sampledQ,]

# Plot Flow Duration Curve
plot(df1$PercentTime, df1$Q, log = "y",
     xlab = "Percent of time that the discharge is equaled or exceeded",
     ylab = "Discharge, in cubic meters per second",
     xaxt = "n",  yaxt = "n",
     type = "l", lwd = 3, cex.lab = 1.5)
axis(1, at = seq(0, 1, 0.2), labels = seq(0, 1, 0.2)*100, tck = 0.04, cex.axis = 1.5)
rug(x = seq(0, 1, 0.1), ticksize = 0.02, side = 1)
axis(2, at = c(1, 10), labels = c(1, 10), tck = 0.04, cex.axis = 1.5)
rug(x = c(seq(0.1, 1, 0.1), seq(1, 10, 1), seq(10, 100, 10)), ticksize = 0.02, side = 2)
axis(3, at = seq(0, 1, 0.2), labels = F, tck = 0.04, cex.axis = 1.5)
rug(x = seq(0, 1, 0.1), ticksize = 0.02, side = 3)
axis(4, at = c(1, 10), labels = F, tck = 0.04, cex.axis = 1.5)
rug(x = c(seq(0.1, 1, 0.1), seq(1, 10, 1), seq(10, 100, 10)), ticksize = 0.02, side = 4)
points(df2$PercentTime, df2$Q, pch = "O", col = "red", cex = 1.5)
legend("topright", inset = 0.05, c("Historic flow duration", "Sampled events"),
       lty = c(1, NA), lwd = c(3, NA), pch = c(NA, "O"), col = c("black", "red"),
       bty = "n", cex = 1.5, title = "Explanation", title.adj = 0.1)