# Cleanup R environment
rm(list=ls())               # Remove data frames and objects
dev.off()                   # Remove plots
cat("\014")                 # Remove results from the console

# Set output to be written with comma or dot for separating decimals
options(OutDec= ".")

# Set working directory
setwd("C:/Taiacupeba_SedimentModel")

# Load data sets
SedData <- read.csv("SedimentData_JUTAChannel.csv",header=T)
  SedData$SAMPLE_DATE <- as.Date(SedData$SAMPLE_DATE, "%m/%d/%Y")

# Compute suspended sediment load
QSS <- SedData$Q * SedData$SSC * 0.0864

# Cumulative sum of discharge and suspended sediment load
cumQ <- cumsum(SedData$Q)
cumQSS <- cumsum(QSS)

# Plot double mass curve
par(mar=c(5,6,4,16))
plot(cumQSS, cumQ, xlab = "Cumulative suspended sediment load, in tons",
     ylab = "Cumulative discharge, in cubic \nmeters per second",
     xaxt = "n", yaxt = "n", pch = "O", cex.lab = 1.5, cex = 1.5)
axis(1, at = pretty(cumQSS, 5), labels = pretty(cumQSS, 5), tck = 0.04, cex.axis = 1.5)
axis(2, at = pretty(cumQ, 10), labels = pretty(cumQ, 10), tck = 0.03, cex.axis = 1.5)
axis(3, at = pretty(cumQSS, 5), labels = F, tck = 0.04, cex.axis = 1.5)
axis(4, at = pretty(cumQ, 10), labels = F, tck = 0.03, cex.axis = 1.5)
lines(c(cumQSS[1], cumQSS[11]-2), c(cumQ[1], cumQ[11]), lwd = 3)
lines(c(cumQSS[12], cumQSS[20]), c(cumQ[12]+5, cumQ[20]-7), lwd = 3)

# Add mean sediment concentration to the plot
text(22, 40, paste(round(mean(SedData$SSC[1:11]), 1), "ppm"), adj = 0, cex = 1.5)
text(82, 120, paste(round(mean(SedData$SSC[12:20]), 1), "ppm"), adj = 0, cex = 1.5)