# Cleanup R environment
rm(list=ls())               # Remove data frames and objects
dev.off()                   # Remove plots
cat("\014")                 # Remove results from the console

# Set output to be written with comma or dot for separating decimals
options(OutDec= ".")

# Set working directory
setwd("C:/Taiacupeba_SedimentModel")

# Load data sets
DailyQ <- read.csv("DailyDischarge_TaiacupebaGuacu.csv",header=T)
  DailyQ$DATE <- as.Date(DailyQ$DATE, "%m/%d/%Y")

# Prepare a data frame for Spearman non-parametric test
spTest <- data.frame(Xt = DailyQ$DISCHARGE)

# Add time index (Tt) and rank (mt)
N <- nrow(spTest)
spTest$Tt <- seq(1, N, 1)
spTest$mt <- rank(spTest$Xt, ties.method = "random")
spTest$fun <- (spTest$mt - spTest$Tt)^2

# Compute test coefficient (rs) and statist (T)
rs <- 1 - ((6*sum(spTest$fun))/((N^3)-N))
T <- rs / sqrt(1/(N-1))

# Set alpha
alpha <- 0.05
z <- qnorm(1 - alpha/2)
ifelse(abs(T) > z,
       paste("Reject null hypothesis (sample is not stationary)"),
       paste("Do not reject null hypothesis (sample is stationary)"))